///////////////////////////////////////////////////////////
////// GibPascal pascal_system.c
////// Released under the GPLv3
////// Written by:
//////    Michael Gibson
//////    (c)2003-2021
///////////////////////////////////////////////////////////

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <limits.h>
#include <process.h>


///////////////////////////
// syn_chk()
///////////////////////////
void syn_chk(char *command)
{
     if(strstr(command,":=") != '\0' && strstr(command,";") == '\0') {  // don't allow a set without a ';'
        printf("Pascal Error: parse error:\n%s\n",command);
        printf("missing ; \n");
        exit(0); 
     }	

     if(strstr(command,"program") != '\0' && strstr(command,";") == '\0') {  // don't allow a set without a ';'
        printf("Pascal Error: parse error:\n%s\n",command);
        printf("missing ; \n");
        exit(0); 
     }	


     if(strstr(command,"')") != '\0' && strstr(command,";") == '\0') {  // don't allow a text based cmd without a ';'
        printf("Pascal Error: parse error:\n%s\n",command);
        printf("missing ; \n");
        exit(0); 
     }	

     if(strstr(command,"{") != '\0' && strstr(command,"}") == '\0') {  // don't allow a '{' comment without a '}'
        printf("Pascal Error: parse error:\n%s\n",command);
        printf("missing } \n");
        exit(0); 
     }	


}
/////////////////////////////
// get current working dir
////////////////////////////
char *get_dir(int debug) {
    
   static char cwd[259];

   if (getcwd(cwd, sizeof(cwd)) != NULL) {
     if(debug==1)printf("**[GetDir] Current working dir: '%s'\n", cwd);
   } else {
       printf("Pascal Error: 015 getcwd() error");
       return 1;
   }

   if(debug==1)printf("**[GetDir ck2] Current working dir: '%s'\n", cwd);
   return cwd;
}

///////////////////////////////////
////// halt
////// Haults code and exits
//////////////////////////////////
void pascal_halt(char *command)
{
 // now POSIX
 if(strcasestr(command,"  halt;")    !='\0')  exit(0);
 if(strcasestr(command,"  halt(0);") !='\0')  exit(0);
 if(strcasestr(command,"  halt(1);") !='\0')  exit(1);
 // halt was matched.  Values above were not matched.
 // POSIX has error exit as 1, so we now default to that
 // because halt; and halt(0); were not matched.
 exit(1);                                                                                                                             
}

///////////////////////////////////////////////////////////
// delay
// pauses/delays execution of commands for a period of time
// intro in ver 1.2
///////////////////////////////////////////////////////////
void pascal_delay(char *command, int debug)
{


  int delaytime=0;
  char systemtext[120];
  int loop=0, loop2=0;

  do{
    loop++;
  }while(command[loop]!='(');
  loop++;
                                                                                                                             
  do{                            
    systemtext[loop2]=command[loop];
    loop++;
    loop2++;
  }while(command[loop]!=')');
  systemtext[loop2]='\0';

  if(debug==1)printf("**[DELAY] delay=%s mill seconds \n",systemtext);
  
  delaytime=atoi(systemtext);

  delaytime=delaytime / 1000;

  if(debug==1)printf("**[DELAY] delay=%i seconds \n",delaytime);

  if(delaytime >=0) sleep(delaytime);

}

/////////////////////////////////////
////// system()
/////////////////////////////////////

void g_pascal_system(char *command,int debug)
{

  char systemtext[128]={'\0'};
  char systemtext2[128]={'\0'};
  char systemtext3[228]={'\0'};
  //char systempre[14];
  
  int loop=0, loop2=0;

  do{
    loop++;
  }while(command[loop]!='\'');
  loop++;
                                                                                                                             
  do{                            
    systemtext[loop2]=command[loop];
    loop++;
    loop2++;
  }while(command[loop]!='\'');
  systemtext[loop2]='\0';
  
  /// now read paramater
  loop2=0;
  do{
    loop++;
  }while(command[loop]!='\'');
  loop++;
                                                                                                                             
  do{                            
    systemtext3[loop2]=command[loop];
    loop++;
    loop2++;
  }while(command[loop]!='\'');
  systemtext3[loop2]='\0';  

  if(debug==1)printf("**[system] system text1= '%s' \n",systemtext);
  sprintf(systemtext2,"%s",systemtext);
  if(debug==1)printf("**[system] system text2= '%s' \n",systemtext2);
  if(debug==1)printf("**[system] system text3= '%s' \n",systemtext3);
  execl(systemtext2, systemtext2,systemtext3, (char*)NULL);
 
}





///////////////////////////////////////
////// get_system()
////// For Unix / Linux systems only
///////////////////////////////////////
void get_system(char *systemvar1, char *systemvar2)
{
  FILE *file_exist;

  //aix       /usr/bin/smit
  //mandrake  /etc/mandrake-release
  //redhat    /etc/redhat-release
  //debian    /etc/debian_version
  //SuSe      /etc/SuSE-release
  //Slackware /etc/slackware-release

   strcpy(systemvar1,"NULL");
   strcpy(systemvar2,"NULL");

   if ((file_exist = fopen("/etc/redhat-release", "r")) != NULL){
     strcpy(systemvar1,"redhat");
     fgets(systemvar2,100,file_exist);
     fclose(file_exist);   
   }

   if ((file_exist = fopen("/etc/mandrake-release", "r")) != NULL){
     strcpy(systemvar1,"mandrake");
     fgets(systemvar2,100,file_exist);
     fclose(file_exist);
   }

   if ((file_exist = fopen("/etc/SuSe-release", "r")) != NULL){
     strcpy(systemvar1,"suse");
     fgets(systemvar2,100,file_exist);
     fclose(file_exist);
   }

   if  ((file_exist = fopen("C:\\Windows\\win.ini","r")) != NULL){
      strcpy(systemvar1,"Microsoft Windows");
      strcpy(systemvar2,"Microsoft Windows");
      //fgets(systemvar2,100,file_exist);
      fclose(file_exist);
   }

   if ((file_exist = fopen("/etc/slackware-release", "r")) != NULL){
     strcpy(systemvar1,"slackware");
     fgets(systemvar2,100,file_exist);
     fclose(file_exist);
   }

   //this has been tested for Debian 1 through 11.1
   //works with many alternate like antix and more
   if ((file_exist = fopen("/etc/debian_version", "r")) != NULL){
     strcpy(systemvar1,"debian");
     fgets(systemvar2,100,file_exist);
     fclose(file_exist);
   }

   if ((file_exist = fopen("/usr/bin/smit", "r")) != NULL){
     strcpy(systemvar1,"aix");
     strcpy(systemvar2,"aix");
     fclose(file_exist);
   }


}

